% Project

clear all;
close all;
clc

% Parameters

Sn = 1000e6;
Pn = 900e6;
wn = 100*pi;
f = 1950;
ft = 1500;

%PU system HVDC Link
Vn = 132e3;
In = Sn/sqrt(3)/Vn;
Zn = Vn^2/Sn;
Ln = Zn;
Cn = 1/(Zn);
Vd_b = sqrt(2/3)*Vn;
Vdc_b = 300e3;
Id_b = sqrt(2)*In;
Idc_b = Sn/Vdc_b;
Sd_b = 2/3*Sn;
Zdc_b = 8/3*Zn

%PU system Turbine Converter

Vnt = 4e3;
Int = Sn/Vnt/sqrt(3);
Intt = Sn/100/Vnt/sqrt(3);
Znt = Vnt^2/Sn
Zntt = Vnt^2/Sn*100;
Lnt = Znt;
Lntt = Zntt;
Cnt = 1/(Znt);
Cntt = 1/(Zntt);
Idt_b = sqrt(2)*Int;
Idtt_b = sqrt(2)*Intt;
Vdt_b = sqrt(2/3)*Vnt;
Vdct_b = 8000;
Idct_b = Sn/Vdct_b;
Idctt_b = Sn/100/Vdct_b;
Zdct_b = 8/3*Znt;
Zdctt_b = 8/3*Zntt;

%Wind Turbine

P_r = 10e6;
R = 141/2;
w_windmax = 100/R;
T_r = P_r/w_windmax;
rho = 1.25;
WS_r = 13;
lambda_r = w_windmax*R/13;
H = 2.65;
E = 4650;
Pint = 0.65;
theta = asin(0.65*0.6/(E/4000/sqrt(2)))*180/pi
Psi = E/(Vnt*sqrt(2/3))/250/w_windmax;
torquetable = zeros(31,1);
omega = zeros(31,1);
for i=1:31;
    if(i>4&&i<14)
        omega(i) = ((i-4)/(13-4)*(13.5-5)+5)/60*2*pi;
    elseif(i>13&&i<27)
        omega(i) = w_windmax;
    end
end
for i=1:31;
    Cp = 0.48;
    if(i>4&&i<14)
        torquetable(i) = Cp*rho/2*R^2*pi*i^3./omega(i)./P_r*w_windmax;
    elseif(i>13&&i<27)
        torquetable(i) = 1;
    else
        torquetable(i) = 0;
    end
end
Cptable = zeros(8,15);
%          2      2.5     3     3.5     4     4.5     5     6       7     8
Cptable = [0,     0.02,  0.05,  0.12,  0.23,  0.35,  0.42,  0.46,  0.42,  0.37, 0.3,  0.17,  0,    0,    0;
           0,     0.04,  0.09,  0.19,  0.3,   0.39,  0.44,  0.48,  0.47,  0.43, 0.39, 0.275, 0.11, 0,    0;
           0.025, 0.07,  0.14,  0.225, 0.33,  0.405, 0.45,  0.48,  0.48,  0.47, 0.45, 0.33,  0.17, 0,    0;
           0.04,  0.09,  0.18,  0.28,  0.34,  0.4,   0.43,  0.47,  0.475, 0.47, 0.43, 0.35,  0.23, 0.1,  0;
           0.05,  0.175, 0.2,   0.29,  0.34,  0.38,  0.41,  0.425, 0.42,  0.4,  0.37, 0.29,  0.18, 0.05, 0;
           0.08,  0.17,  0.225, 0.27,  0.28,  0.28,  0.27,  0.21,  0.12,  0,    0,    0,     0,    0,    0;
           0.12,  0.17,  0.19,  0.18,  0.165, 0.12,  0.055, 0,     0,     0,    0,    0,     0,    0,    0;
           0.12,  0.18,  0.12,  0.075, 0,     0,     0,     0,     0,     0,    0,    0,     0,    0,    0];

x = [2, 2.5, 3, 3.5, 4, 4.5, 5, 6, 7, 8, 9, 10, 11, 12, 13];
%plot(x,Cptable(1,:),x,Cptable(2,:),x,Cptable(3,:),x,Cptable(4,:),x,Cptable(5,:),x,Cptable(6,:),x,Cptable(7,:),x,Cptable(8,:));

%List of constants HVDC Link

Lpu = 0.15/100/pi;
Ltpu = 0.2/100/pi;
tauc = 10e-3;
C = tauc*2*2*Pn/Vdc_b^2
Ct = tauc*2*2*Sn/Vdct_b^2
Ctt = Ct/100;
Cpu = 1/(2*100*pi);
Cf = 60*10^6/Vn^2/(2*pi*f)
Cfpu = Cf/Cn;
Rf = 25/Cf/(2*pi*f)
Lf = 1/(2*pi*f)^2/Cf
Rc = 0.67;
Lc = (38.4e-3)
Ltc = 0.807e-3;
Rpu = 0.01;
Ts= 1/f/2;
wq = 12*2*pi;
wAC = 100*2*pi;
a = 2;

% Controler parameters HVDC Link

Ti = Lpu/Rpu*1.3
kp = Lpu*f
ki = kp/Ti; %
kpneg = kp
kineg = kpneg/Ti
Teq = (2*Ti+Ts) %
Tidc = Teq*a^2 %
kpdc = C*100*pi/Cn/(a*Teq)*1.2 %
kidc = kpdc/Tidc %
kpQ = wq*2*Teq/3 %
kiQ = kpQ/Tidc %
kpAC = wAC*f*Teq*Cfpu
Tiac = Tidc
kiAC = kpAC/Tiac

% Controller parameters WTG

kpt = Lpu*ft*0.8
Tit = Ltpu/Rpu*1.3
kit = kpt/Tit
Teqt = (2*Tit+Ts)
Titdc = Teq*a^2
kptneg = kpt
kitneg = kptneg/Tit/20
kptdc = Ct*100*pi/Cnt/(a*Teqt)/8
kitdc = kptdc/Titdc
kptQ = wq*3*2*Teqt/8
kitQ = kptQ/Titdc
kpf = 8;
kif = kpf/a^2/(tauc)

inputfilterC = 3e-4*1950/1500;
Q = 200;
lim = 4/pi;
shortON = 0.350;
shortOFF = shortON+0.120;
Ktt=3*Psi*250/2*R/lambda_r
kpte = 1.5;
Tite = a^2*(Teq+H)
kite = kpte/Tite
kpbeta = 5;
Betaratelimit = 0.03;
Tbeta = 2;
kibeta = kpbeta/Tbeta;

ksogi = sqrt(2);
kisogi = 2*sqrt(2);

save('constants');